"""
AgentSudo Framework Adapters

Provides integration with web frameworks:
- FastAPI: Middleware for endpoint protection

Usage:
    from agentsudo.adapters.fastapi import AgentSudoMiddleware, require_scope
"""

__all__ = [
    "fastapi",
]
